@@ -63,8 +63,8 @@ class Service(enum.Enum):
     FptAi = enum.auto()
     PyThaiNLP = enum.auto()
     Spacy = enum.auto()
-    ArgosTranslate = enum.auto()
     Wenlin = enum.auto()
+    LibreTranslate = enum.auto()
 
 class Gender(enum.Enum):
     Male = enum.auto()
