@@ -27,8 +27,8 @@ if LOAD_NLP_MODELS:
     import cloudlanguagetools.easypronunciation
     import cloudlanguagetools.pythainlp
     import cloudlanguagetools.spacy
-    import cloudlanguagetools.argostranslate
     import cloudlanguagetools.wenlin
+    import cloudlanguagetools.libretranslate    
 
 class ServiceManager():
     def  __init__(self):
@@ -51,8 +51,8 @@ class ServiceManager():
             self.services[cloudlanguagetools.constants.Service.PyThaiNLP.name] = cloudlanguagetools.pythainlp.PyThaiNLPService()
             self.services[cloudlanguagetools.constants.Service.Spacy.name] = cloudlanguagetools.spacy.SpacyService()
             self.services[cloudlanguagetools.constants.Service.MandarinCantonese.name] = cloudlanguagetools.mandarincantonese.MandarinCantoneseService()            
-            self.services[cloudlanguagetools.constants.Service.ArgosTranslate.name] = cloudlanguagetools.argostranslate.ArgosTranslateService()
             self.services[cloudlanguagetools.constants.Service.Wenlin.name] = cloudlanguagetools.wenlin.WenlinService()
+            self.services[cloudlanguagetools.constants.Service.LibreTranslate.name] = cloudlanguagetools.libretranslate.LibreTranslateService()
 
     def configure_default(self):
         # use the stored keys to configure services
@@ -248,4 +248,25 @@ class ServiceManager():
         """returns an enum from languages.Language"""
         service = self.services[cloudlanguagetools.constants.Service.Azure.name]
         result = service.detect_language(text_list)
-        return result
\ No newline at end of file
+        return result
+
+    def service_cost(self, text, service_name, request_type: cloudlanguagetools.constants.RequestType):
+        """return the cost of using a service, in characters"""
+        service = cloudlanguagetools.constants.Service[service_name]
+        character_length = len(text)
+        
+        FREE_SERVICES = [
+            cloudlanguagetools.constants.Service.MandarinCantonese,
+            cloudlanguagetools.constants.Service.LibreTranslate,
+            cloudlanguagetools.constants.Service.Epitran,
+            cloudlanguagetools.constants.Service.Wenlin,
+            cloudlanguagetools.constants.Service.PyThaiNLP,
+        ]
+
+        if service in FREE_SERVICES:
+            return 0
+
+        if service == cloudlanguagetools.constants.Service.Naver and request_type == cloudlanguagetools.constants.RequestType.audio:
+            return 6 * character_length
+
+        return character_length
\ No newline at end of file
